@@ -33,7 +33,7 @@
 #include <logging.h>
 
 // Make the windows-nonexistent alarm an empty call
-#ifdef WIN32
+#ifdef _WIN32
 #define alarm(argument) (void)0
 #define signal_alarm(fn) (void)0
 #else
@@ -47,8 +47,8 @@ using namespace std;
 // So far, this function must be used and up to this length of payload.
 const size_t DEFAULT_CHUNK = 1316;
 
-const logging::LogFA SRT_LOGFA_APP = 10;
-logging::Logger applog(SRT_LOGFA_APP, srt_logger_config, "srt-mplex");
+const srt_logging::LogFA SRT_LOGFA_APP = 10;
+srt_logging::Logger applog(SRT_LOGFA_APP, srt_logger_config, "srt-mplex");
 
 volatile bool siplex_int_state = false;
 void OnINT_SetIntState(int)
@@ -545,7 +545,7 @@ int main( int argc, char** argv )
     }
 
     string loglevel = Option<OutString>(params, "error", "ll", "loglevel");
-    logging::LogLevel::type lev = SrtParseLogLevel(loglevel);
+    srt_logging::LogLevel::type lev = SrtParseLogLevel(loglevel);
     UDT::setloglevel(lev);
     UDT::addlogfa(SRT_LOGFA_APP);
 
