@@ -29,7 +29,7 @@ written by
 
 #include <sys/types.h>
 
-#ifdef WIN32
+#ifdef _WIN32
    #include <winsock2.h>
    #include <ws2tcpip.h>
    #if defined(_MSC_VER)
