@@ -20,7 +20,7 @@ written by
 *****************************************************************************/
 
 #include <string.h>		/* memcpy */
-#ifdef WIN32
+#ifdef _WIN32
     #include <winsock2.h>
     #include <ws2tcpip.h>
     #include <win/wintime.h>
